ui
==

This subpackage contains the user interfaces of the TurboCtl program.

.. toctree::

    control_interface.rst
    table.rst
    docs.rst
    command_line_ui.rst
    widgets.rst
    advanced_tui.rst
    queuefile.rst
    status_format.rst
   

